@@ -1,7 +1,6 @@
-/* $Id: er_fileutils.c,v 1.37 2013-02-12 15:37:46 rpalsa Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2012 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2013-02-12 15:37:46 $
- * $Revision: 1.37 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -629,8 +621,8 @@ if ((stat(srcpath,&sb) == 0) && (stat(dstpath,&db) == 0))
    {
    if (ER_TRACEFLAG)
       {
-      (void) sprintf(trace_msg, "in-inode = %d, out-inode = %d",
-                     sb.st_ino,db.st_ino);
+      (void) sprintf(trace_msg, "in-inode = %ld, out-inode = %ld",
+                     (long)sb.st_ino, (long)db.st_ino);
       ER_TRACEX(trace_msg)
       }
    if (sb.st_ino == db.st_ino) 
@@ -793,112 +785,113 @@ return 0;
 int er_fileutils_link (const char *link_path, const char *file_path)
 
 {
-char linkname[FILEMAX + 1];
-char *s;
+    char linkname[FILEMAX + 1];
+    const char *s;
 
-int  len;
+    int  len;
 
-struct stat lb;
+    struct stat lb;
 
 
 
-ER_TRACE(__func__)
+    ER_TRACE(__func__)
 
 
-/* Check if the input file is readable */
+    /* Check if the input file is readable */
 
-if (access (file_path, R_OK))
-   {
-   cpl_msg_error (er_func, "Product file is unreadable: %s", file_path);
-   return EXIT_FAILURE;
-   }
+    if (access (file_path, R_OK))
+    {
+        cpl_msg_error (er_func, "Product file is unreadable: %s", file_path);
+        return EXIT_FAILURE;
+    }
 
 
-/* pull out the file name */
+    /* pull out the file name */
 
-s = strrchr (file_path, '/');			/* points to last '/' */
-if (s == NULL) 
-   len = (int) strlen(file_path); 
-else
-   {
-   s++;
-   len = (int) strlen(s);
-   }
-
-len = (int) strlen(link_path) + len + 1;
-if (len > FILEMAX)
-   {
-   cpl_msg_error (er_func, "Buffer overflow - fatal error");
-   return EXIT_FAILURE;
-   }
-(void) snprintf (linkname, (size_t)FILEMAX, "%s/%s", link_path, s);
+    s = strrchr (file_path, '/');			/* points to last '/' */
+    if (s == NULL)
+    {
+        s = file_path;
+    }
+    else
+    {
+        ++s;
+    }
+    len = (int) strlen(s);
+    len = (int) strlen(link_path) + len + 1;
+    if (len > FILEMAX)
+    {
+        cpl_msg_error (er_func, "Buffer overflow - fatal error");
+        return EXIT_FAILURE;
+    }
+    (void) snprintf (linkname, (size_t)FILEMAX, "%s/%s", link_path, s);
 
 
-/* check if link already there... */
+    /* check if link already there... */
 
-/* if (fileutils_file_is_there (linkname) == 1)  */
-if (fileutils_file_exists (linkname) == 1) 
-   {
-   cpl_msg_warning (er_func, "the link %s already exists - will be overwritten!",linkname);
-   }
+    /* if (fileutils_file_is_there (linkname) == 1)  */
+    if (fileutils_file_exists (linkname) == 1)
+    {
+        cpl_msg_warning (er_func, "the link %s already exists - will be overwritten!",linkname);
+    }
 
 
-/*
- * To export the file to the archive usually a symbolic link to the
- * product file is created. But symbolic links are not conforming to
- * the ANSI C standard. If symbolic links are not available the file
- * is just copied. Hard links might be an alternative but they cannot
- * be used across file systems, so a real copy is created here.
- */
+    /*
+     * To export the file to the archive usually a symbolic link to the
+     * product file is created. But symbolic links are not conforming to
+     * the ANSI C standard. If symbolic links are not available the file
+     * is just copied. Hard links might be an alternative but they cannot
+     * be used across file systems, so a real copy is created here.
+     */
 
 #if defined HAVE_LSTAT && defined HAVE_SYMLINK
 
-if (lstat (linkname, &lb))
-   {
-   if (errno != ENOENT)
-      {
-      cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
-      return EXIT_FAILURE;
-      }
-   }
-else
-   {
-   if (S_ISLNK (lb.st_mode))
-      (void) unlink (linkname);
-   else
-      {
-      cpl_msg_error (er_func, "Not a symbolic link: %s", linkname);
-      return EXIT_FAILURE;
-      }
-   }
+    if (lstat (linkname, &lb))
+    {
+        if (errno != ENOENT)
+        {
+            cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
+            return EXIT_FAILURE;
+        }
+    }
+    else
+    {
+        if (S_ISLNK (lb.st_mode))
+            (void) unlink (linkname);
+        else
+        {
+            cpl_msg_error (er_func, "Not a symbolic link: %s", linkname);
+            return EXIT_FAILURE;
+        }
+    }
 
-if (symlink (file_path, linkname) != 0)
-   {
-   cpl_msg_error (er_func, "Cannot create symbolic link for %s", file_path);
-   return EXIT_FAILURE;
-   }
+    if (symlink (file_path, linkname) != 0)
+    {
+        cpl_msg_error (er_func, "Cannot create symbolic link for %s", file_path);
+        return EXIT_FAILURE;
+    }
 
 #else
 
-if (stat (linkname, &lb))
-   {
-   if (errno != ENOENT)
-      {
-      cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
-      return EXIT_FAILURE;
-      }
-   }
-else
-   (void) unlink (linkname);
+    if (stat (linkname, &lb))
+    {
+        if (errno != ENOENT)
+        {
+            cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
+            return EXIT_FAILURE;
+        }
+    }
+    else
+        (void) unlink (linkname);
 
-if (fileutils_copy (file_path, linkname) < 0)
-   {
-   cpl_msg_error (er_func, "Cannot copy %s", file_path);
-   return EXIT_FAILURE;
-   }
+    if (fileutils_copy (file_path, linkname) < 0)
+    {
+        cpl_msg_error (er_func, "Cannot copy %s", file_path);
+        return EXIT_FAILURE;
+    }
 #endif
 
-return EXIT_SUCCESS;
+    return EXIT_SUCCESS;
 
 }                               /* End of er_fileutils_link() */
 
