@@ -1,7 +1,6 @@
-/* $Id: er_help.c,v 1.41 2013-01-28 10:51:15 cgarcia Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2004 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: cgarcia $
- * $Date: 2013-01-28 10:51:15 $
- * $Revision: 1.41 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -447,35 +439,30 @@ return;
 /**********************************************************************/
 
 static void er_help_print_paramlist (cpl_parameterlist *param_list)
-
 {
-cpl_parameter   *param  = NULL;  	/* Parameter */
 
-int  ic;
+    cpl_parameter   *param  = NULL;  	/* Parameter */
 
 
+    ER_TRACE(__func__)
 
+    /* Loop through all the parameters in the list */
 
-ER_TRACE(__func__)
+    param = cpl_parameterlist_get_first(param_list);
 
+    while (param != NULL)		/* Create the description text */
+    {
+        const char *alias = cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI);
 
-/* Loop through all the parameters in the list */
+        if (alias && cpl_parameter_is_enabled(param, CPL_PARAMETER_MODE_CLI)) {
+            er_help_create_description(param, TRUE);
+            er_paramutils_print_key_desc(COMMAND_LINE_PREFIX, alias, wdsc);
+        }
+        param = cpl_parameterlist_get_next(param_list);	/* get the next parameter */
+    }
 
-param = cpl_parameterlist_get_first(param_list);
-ic = 0;
-
-while (param != NULL)		/* Create the description text */
-   {		
-   er_help_create_description(param, TRUE);
-
-   er_paramutils_print_key_desc( COMMAND_LINE_PREFIX,
-                 cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI), wdsc);
-
-   param = cpl_parameterlist_get_next(param_list);	/* get the next parameter */
-   }
-
-				/* Pad with an additional blank line */
-printf( "\n" );
+    /* Pad with an additional blank line */
+    printf( "\n" );
 
 } 
 
