@@ -1,7 +1,6 @@
-/* $Id: er_json.h,v 1.4 2013-02-22 10:43:37 cgarcia Exp $
- *
+/*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2006 European Southern Observatory
+ * Copyright (C) 2001-2016 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: cgarcia $
- * $Date: 2013-02-22 10:43:37 $
- * $Revision: 1.4 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -46,5 +38,5 @@ cpl_error_code er_recipe_parameterlist_to_json(const cpl_parameterlist * plist,
                                                const char * json_file);
 char * er_json_escape_string(const char * str);
 
-
+CPL_END_DECLS
 #endif
