@@ -1,7 +1,6 @@
-/* $Id: er_paf.c,v 1.20 2013-08-23 15:04:22 cgarcia Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2004 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: cgarcia $
- * $Date: 2013-08-23 15:04:22 $
- * $Revision: 1.20 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -453,7 +445,7 @@ struct er_paf_config * er_paf_read_config_file
  * saved in the PAF file. It includes the mandatory keywords, the QC 
  * keywords and the specified keywords in the config file and the ARCFILE
  * keyword which comes from a external frame (the first raw frame from the 
- * framset).
+ * frameset).
  * This function should be used only for single extension products  
  */
 /**********************************************************************/
@@ -495,7 +487,7 @@ cpl_propertylist* er_paf_fill_paf_proplist_single_hdu
 	cpl_propertylist_copy_property_regexp(matched_keys, all_keywords,key,0);
 	if(cpl_propertylist_get_size(matched_keys) == 0)
 	    cpl_msg_debug(er_func, "Cannot find keywords matching %s", key);
-	cpl_propertylist_copy_property_regexp(paf_proplist, matched_keys,"",0);
+	cpl_propertylist_append(paf_proplist, matched_keys);
 	cpl_propertylist_delete(matched_keys);
 	}
     
@@ -597,7 +589,7 @@ cpl_propertylist* er_paf_fill_paf_proplist_multi_hdu
 		all_keywords_hdu_ext,key,0);
 	if(cpl_propertylist_get_size(matched_keys) == 0)
 	    cpl_msg_debug(er_func, "Cannot find keywords matching %s", key);
-	cpl_propertylist_copy_property_regexp(paf_proplist, matched_keys,"",0);
+	cpl_propertylist_append(paf_proplist, matched_keys);
 	cpl_propertylist_delete(matched_keys);
 	}
     
@@ -614,7 +606,7 @@ cpl_propertylist* er_paf_fill_paf_proplist_multi_hdu
 	cpl_propertylist_delete(all_keywords_hdu_ext);
 	return qc_keywords;
 	}
-    cpl_propertylist_copy_property_regexp(paf_proplist, qc_keywords,"",0);
+    cpl_propertylist_append(paf_proplist, qc_keywords);
     cpl_propertylist_delete(qc_keywords);
     
     /* Bad return if there are no keywords at all */
