@@ -1,7 +1,6 @@
-/* $Id: er_params.c,v 1.64 2013-01-03 17:55:39 cgarcia Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2009 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: cgarcia $
- * $Date: 2013-01-03 17:55:39 $
- * $Revision: 1.64 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #   include <config.h>
 #endif
@@ -44,8 +36,6 @@
 #include <fitsio.h>
 */
 
-#include <cpl.h>
-
 #include "ltdl.h"
 
 
