@@ -1,7 +1,6 @@
-/* $Id: er_params.h,v 1.7 2007-06-04 15:45:48 kbanse Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2004 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,18 +17,11 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: kbanse $
- * $Date: 2007-06-04 15:45:48 $
- * $Revision: 1.7 $
- * $Name: not supported by cvs2svn $
- */
-
-
-
 #ifndef ER_PARAMS_H
 #define ER_PARAMS_H
 
+#include <cpl.h>
+
 CPL_BEGIN_DECLS
 
 
