@@ -1,7 +1,6 @@
-/* $Id: er_paramutils.c,v 1.42 2013-02-19 15:54:03 rpalsa Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2004 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,15 +17,8 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2013-02-19 15:54:03 $
- * $Revision: 1.42 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
-#   include "config.h"
+#  include "config.h"
 #endif
 
 #include <stdio.h>
@@ -496,7 +488,7 @@ while (p != NULL)
       tmp_string = cpl_parameter_get_string (p);
       i = (int) strlen(tmp_string);
       if (i > MAXSTR)
-         (void) sprintf (tmp_cmdl_descr, "%MAXSTR.MAXSTR", tmp_string);
+         (void) snprintf (tmp_cmdl_descr, MAXSTR, "%s", tmp_string);
       else
          (void) sprintf (tmp_cmdl_descr, "%s", tmp_string ? tmp_string : "-");
       break;
