@@ -1,7 +1,6 @@
-/* $Id: er_plugin.c,v 1.115 2013-02-19 15:54:36 rpalsa Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2012 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,15 +17,8 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: rpalsa $
- * $Date: 2013-02-19 15:54:36 $
- * $Revision: 1.115 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
-#   include <config.h>
+#  include <config.h>
 #endif
 
 #include <stdio.h>
@@ -400,19 +392,31 @@ while( fgets (line, (SIZE_C-1), fp))
                }
             else				/* Yes, bad filename */	
                {
+               char * tagmsg = n >= 2
+                   ? cpl_sprintf("tag '%s'", tag)
+                   : cpl_sprintf("no tag");
+               char * groupmsg = n >= 3
+                   ? cpl_sprintf("group '%s'", group)
+                   : cpl_sprintf("no group");
+
                if (flag_check_sof_exist)
         	   {
                    cpl_msg_error (er_func,
-                        "The input data file '%s', in line %d of the SOF "
-                        "file does not exist...", path, line_number);
+                        "Could not open the input file '%s' with %s and %s in "
+                        "line %d of the SOF '%s'", path, tagmsg, groupmsg,
+                        line_number, name);
                    load_sucesfull = 0;
         	   }
                else
                   {
                   cpl_msg_debug (er_func,
-                       "The input data file '%s', in line %d of the SOF "
-                       "file, does not exist...", path, line_number);
+                        "Could not open the input file '%s' with %s and %s in "
+                        "line %d of the SOF '%s'", path, tagmsg, groupmsg,
+                        line_number, name);
                   }
+               cpl_free(tagmsg);
+               cpl_free(groupmsg);
+
                }
             }
 
@@ -992,7 +996,8 @@ char **val_recipe_dirs = NULL,
 char *cptr, 
      *plugin_conf_file_global=NULL,
      *plugin_conf_file_local=NULL,
-     library_path[MAXSTRLENCONF];
+     library_path[MAXSTRLENCONF],
+     cmdline[MAXSTRLENCONF];
 
 char *help_str = NULL;
 
@@ -1079,15 +1084,24 @@ if (log_err != CPL_ERROR_NONE)
    (void) printf ("          (Check write permission for temporary files.)\n");
    }
 
-/* always save used library versions in logfile (only) */
+/*
+ * Always save the library dependencies and the invocation command line to
+ * the logfile (only)
+ */
 
 cpl_msg_set_level (CPL_MSG_OFF);
 cdescr = cpl_get_description(CPL_DESCRIPTION_DEFAULT);
 
-(void) cpl_msg_info(er_func,"Esorex, version %s", PACKAGE_VERSION);
-/*
-*/
-(void) cpl_msg_info(er_func,"using the libraries: %s\n",cdescr);
+(void) cpl_msg_info(er_func,"This is EsoRex, version %s", PACKAGE_VERSION);
+(void) cpl_msg_info(er_func,"using the libraries: %s",cdescr);
+
+sz = 0;
+for (i=0; i < argc - 1; ++i) {
+    int nc = snprintf(&cmdline[sz], MAXSTRLENCONF, "%s ", argv[i]);
+    sz += nc;
+}
+sz = snprintf(&cmdline[sz], MAXSTRLENCONF, "%s", argv[argc - 1]);
+(void) cpl_msg_info(er_func,"Invocation command line was: %s", cmdline);
 cpl_msg_set_level (msg_sev_terminal);
 
 
@@ -1628,15 +1642,6 @@ if (flag_plugin_found != 0)			/*  = TRUE */
 
   plugin_deinit:
 
-#if 0
-   if (f_val_unload_plugin == 0) 	/* we want to keep all memory */
-      {
-      cpl_msg_info(er_func,
-          "The plugin info will not be removed after execution!");
-      goto final_end;			/* as it is for debugging! */
-      }
-#endif
-
    plugin_func_deinit = cpl_plugin_get_deinit ((cpl_plugin *) trecipe);
 
    if (plugin_func_deinit != NULL)
@@ -1800,7 +1805,6 @@ else if (trecipe != NULL)
    cpl_plugin_delete ((cpl_plugin *) trecipe); 
    }
 
-final_end:
 if (e_code == -99999) e_code = 0;
 return e_code;
 }                               /* End of plugin_process_plugin() */
