@@ -1,7 +1,6 @@
-/* $Id: er_pluginlist.c,v 1.39 2012-02-23 13:46:14 kbanse Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2006 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: kbanse $
- * $Date: 2012-02-23 13:46:14 $
- * $Revision: 1.39 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #   include <config.h>
 #endif
@@ -244,7 +236,11 @@ if (dp == NULL)
 
 ldir = (int) strlen(dirname);
 fqfn = cpl_malloc ((size_t) filename_len);
-if (fqfn == NULL) return;
+if (fqfn == NULL) 
+    {
+        closedir(dp);
+        return;
+    }
 
 while ((entry = readdir (dp)) != NULL)
    {
