@@ -1,7 +1,6 @@
-/* $Id: er_stringarray.h,v 1.6 2009-05-06 14:08:06 cgarcia Exp $
- *
+/*
  *   This file is part of the ESO Common Pipeline Library
- *   Copyright (C) 2001-2004 European Southern Observatory
+ *   Copyright (C) 2001-2016 European Southern Observatory
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,20 +17,13 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: cgarcia $
- * $Date: 2009-05-06 14:08:06 $
- * $Revision: 1.6 $
- * $Name: not supported by cvs2svn $
- */
-
-
-
-CPL_BEGIN_DECLS
-
 #ifndef ER_STRINGARRAY_H
 #define ER_STRINGARRAY_H
 
+#include <cpl_macros.h>
+
+CPL_BEGIN_DECLS
+
 typedef struct er_stringarray_s er_stringarray_t;
 
 
@@ -46,12 +38,8 @@ extern int er_stringarray_size(er_stringarray_t *);
 extern void er_stringarray_print(er_stringarray_t *);
 extern void er_stringarray_append(er_stringarray_t *, char *);
 
-#endif /* ER_STRINGARRAY_H */
-
-
 CPL_END_DECLS
 
-
-
+#endif /* ER_STRINGARRAY_H */
 /* End of file */
 
